# Deep Dive

A deep dive into various approaches and reasonings within the PyMedPhys
repository. The target audience are either contributors who want to understand
more about something within the repository or external developers who would
like to replicate something that PyMedPhys has undergone.

```{toctree}
:maxdepth: 1

why-open-source
create-streamlit-exe
```
